@@ -440,7 +440,7 @@ def broyden_class_update(y, s, mat, phi=None, v=None):
         return np.outer(y, y.T) / b - np.outer(u, u.T) / c
 
     if v is None:
-        rho = np.sqrt(b / c)
+        rho = np.sqrt(b / c) if c > 0 else 0  # c == 0 iff u == 0
         v = y + (1-phi) * rho * u
 
     z = y - mat.dot(s)
